@@ -21,28 +21,41 @@ def _auto_logout(request: HttpRequest, options):
         now = datetime.now()
 
     if options.get('SESSION_TIME') is not None:
-        ttl = timedelta(seconds=options['SESSION_TIME'])
+        if isinstance(options['SESSION_TIME'], timedelta):
+            ttl = options['SESSION_TIME']
+        elif isinstance(options['SESSION_TIME'], int):
+            ttl = timedelta(seconds=options['SESSION_TIME'])
+        else:
+            raise TypeError(f"AUTO_LOGOUT['SESSION_TIME'] should be `int` or `timedelta`, "
+                            f"not `{type(options['SESSION_TIME']).__name__}`.")
+
         time_expired = user.last_login < now - ttl
         should_logout |= time_expired
         logger.debug('Check SESSION_TIME: %s < %s (%s)', user.last_login, now, time_expired)
 
     if options.get('IDLE_TIME') is not None:
-        ttl = timedelta(seconds=options['IDLE_TIME'])
-
-        if 'django_auto_logout_last_touch' in request.session:
-            last_touch = datetime.fromisoformat(request.session['django_auto_logout_last_touch'])
+        if isinstance(options['IDLE_TIME'], timedelta):
+            ttl = options['IDLE_TIME']
+        elif isinstance(options['IDLE_TIME'], int):
+            ttl = timedelta(seconds=options['IDLE_TIME'])
         else:
-            last_touch = now
-            request.session['django_auto_logout_last_touch'] = last_touch.isoformat()
+            raise TypeError(f"AUTO_LOGOUT['IDLE_TIME'] should be `int` or `timedelta`, "
+                            f"not `{type(options['IDLE_TIME']).__name__}`.")
 
-        time_expired = last_touch < now - ttl
+        if 'django_auto_logout_last_request' in request.session:
+            last_req = datetime.fromisoformat(request.session['django_auto_logout_last_request'])
+        else:
+            last_req = now
+            request.session['django_auto_logout_last_request'] = last_req.isoformat()
+
+        time_expired = last_req < now - ttl
         should_logout |= time_expired
-        logger.debug('Check IDLE_TIME: %s < %s (%s)', last_touch, now, time_expired)
+        logger.debug('Check IDLE_TIME: %s < %s (%s)', last_req, now, time_expired)
 
         if should_logout:
-            del request.session['django_auto_logout_last_touch']
+            del request.session['django_auto_logout_last_request']
         else:
-            request.session['django_auto_logout_last_touch'] = now.isoformat()
+            request.session['django_auto_logout_last_request'] = now.isoformat()
 
     if should_logout:
         logger.debug('Logout user %s', user)
